Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS App Mesh.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS App Mesh - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for AWS App Mesh

AWS App Mesh (service prefix: `appmesh` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS App Mesh
- Resource Types Defined by AWS App Mesh
- Condition Keys for AWS App Mesh

## Actions Defined by AWS App Mesh

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateGatewayRoute | Creates a gateway route that is associated with a virtual gateway. | Write | gatewayRoute* |  |
virtualService |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateMesh | Creates a service mesh. | Write | mesh* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateRoute | Creates a route that is associated with a virtual router. | Write | route* |  |
virtualNode |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateVirtualGateway | Creates a virtual gateway within a service mesh. | Write | virtualGateway* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateVirtualNode | Creates a virtual node within a service mesh. | Write | virtualNode* |  |
virtualService |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateVirtualRouter | Creates a virtual router within a service mesh. | Write | virtualRouter* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateVirtualService | Creates a virtual service within a service mesh. | Write | virtualService* |  |
virtualNode |  |
virtualRouter |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteGatewayRoute | Deletes an existing gateway route. | Write | gatewayRoute* |  |
DeleteMesh | Deletes an existing service mesh. | Write | mesh* |  |
DeleteRoute | Deletes an existing route. | Write | route* |  |
DeleteVirtualGateway | Deletes an existing virtual gateway. | Write | virtualGateway* |  |
DeleteVirtualNode | Deletes an existing virtual node. | Write | virtualNode* |  |
DeleteVirtualRouter | Deletes an existing virtual router. | Write | virtualRouter* |  |
DeleteVirtualService | Deletes an existing virtual service. | Write | virtualService* |  |
DescribeGatewayRoute | Describes an existing gateway route. | Read | gatewayRoute* |  |
DescribeMesh | Describes an existing service mesh. | Read | mesh* |  |
DescribeRoute | Describes an existing route. | Read | route* |  |
DescribeVirtualGateway | Describes an existing virtual gateway. | Read | virtualGateway* |  |
DescribeVirtualNode | Describes an existing virtual node. | Read | virtualNode* |  |
DescribeVirtualRouter | Describes an existing virtual router. | Read | virtualRouter* |  |
DescribeVirtualService | Describes an existing virtual service. | Read | virtualService* |  |
ListGatewayRoutes | Returns a list of existing gateway routes in a service mesh. | List | virtualGateway* |  |
ListMeshes | Returns a list of existing service meshes. | List |  |  |
ListRoutes | Returns a list of existing routes in a service mesh. | List | virtualRouter* |  |
ListTagsForResource | List the tags for an App Mesh resource. | List | gatewayRoute |  |
mesh |  |
route |  |
virtualGateway |  |
virtualNode |  |
virtualRouter |  |
virtualService |  |
ListVirtualGateways | Returns a list of existing virtual gateways in a service mesh. | List | mesh* |  |
ListVirtualNodes | Returns a list of existing virtual nodes. | List | mesh* |  |
ListVirtualRouters | Returns a list of existing virtual routers in a service mesh. | List | mesh* |  |
ListVirtualServices | Returns a list of existing virtual services in a service mesh. | List | mesh* |  |
StreamAggregatedResources | Allows an Envoy Proxy to receive streamed resources for an App Mesh endpoint (VirtualNode or VirtualGateway). | Read | virtualGateway |  |
virtualNode |  |
TagResource | Associates the specified tags to a resource with the specified resourceArn. | Write | gatewayRoute |  |
mesh |  |
route |  |
virtualGateway |  |
virtualNode |  |
virtualRouter |  |
virtualService |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Deletes specified tags from a resource. | Write | gatewayRoute |  |
mesh |  |
route |  |
virtualGateway |  |
virtualNode |  |
virtualRouter |  |
virtualService |  |
| aws:TagKeys |
UpdateGatewayRoute | Updates an existing gateway route for a specified service mesh and virtual gateway. | Write | gatewayRoute* |  |
virtualService |  |
UpdateMesh | Updates an existing service mesh. | Write | mesh* |  |
UpdateRoute | Updates an existing route for a specified service mesh and virtual router. | Write | route* |  |
virtualNode |  |
UpdateVirtualGateway | Updates an existing virtual gateway in a specified service mesh. | Write | virtualGateway* |  |
UpdateVirtualNode | Updates an existing virtual node in a specified service mesh. | Write | virtualNode* |  |
UpdateVirtualRouter | Updates an existing virtual router in a specified service mesh. | Write | virtualRouter* |  |
UpdateVirtualService | Updates an existing virtual service in a specified service mesh. | Write | mesh* |  |
virtualNode |  |
virtualRouter |  |

## Resource Types Defined by AWS App Mesh

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
mesh | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}` | aws:ResourceTag/${TagKey}
virtualService | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualService/$ { VirtualServiceName}` | aws:ResourceTag/${TagKey}
virtualNode | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualNode/$ { VirtualNodeName}` | aws:ResourceTag/${TagKey}
virtualRouter | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualRouter/$ { VirtualRouterName}` | aws:ResourceTag/${TagKey}
route | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualRouter/$ { VirtualRouterName}/route/$ { RouteName}` | aws:ResourceTag/${TagKey}
virtualGateway | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualGateway/$ { VirtualGatewayName}` | aws:ResourceTag/${TagKey}
gatewayRoute | `arn:$ { Partition}:appmesh:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualGateway/$ { VirtualGatewayName}/gatewayRoute/$ { GatewayRouteName}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS App Mesh

AWS App Mesh defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request. | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource. | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.